pub struct CliConfig {
pub from_base: u16,
pub to_base: u16,
pub from_table: Option<String>,
pub to_table: Option<String>,
}Expand description
Convert data base, from stdin to stdout
Fields
from_base: u16Input base
to_base: u16Output base
from_table: Option<String>Input mapping table; maps bytes to characters
The length of this string should be equal to from_base
to_table: Option<String>Output mapping table; maps bytes to characters
The length of this string should be equal to to_base